==> tw-api-5.0.39-20240715.094951-2-sources.jar: com/elitesland/tw/tw5/api/prd/personplan/query/PersonPlanVersionQuery.java <==
package com.elitesland.tw.tw5.api.prd.personplan.query;

import com.elitesland.tw.tw5.api.common.TwQueryParam;
import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;

import java.io.Serializable;

/**
 * 人员规划版本
 *
 * @author wangly
 * @date 2024-04-07
 */
@Getter
@Setter
public class PersonPlanVersionQuery extends TwQueryParam implements Serializable {
    /**
     * 记录唯一ID 精确
     */
    @ApiModelProperty("记录唯一ID")
    private Long id;
    /**
     * 资源规划主表id
     */
    @ApiModelProperty("资源规划主表id")
    private Long planId;
    /**
     * 类型 精确
     */
    @ApiModelProperty("类型")
    private String planType;
    /**
     * 版本名称 精确
     */
    @ApiModelProperty("版本名称")
    private String versionName;
    /**
     * 版本信息 精确
     */
    @ApiModelProperty("版本信息")
    private String changeContent;
    /**
     * 变更单据id 精确
     */
    @ApiModelProperty("变更单据id")
    private Long objId;
    /**
     * 版本号 精确
     */
    @ApiModelProperty("版本号")
    private Integer versionNo;
    /**
     * 变更状态 精确
     */
    @ApiModelProperty("变更状态")
    private String status;
    /**
     * 流程状态 精确
     */
    @ApiModelProperty("流程状态")
    private String apprStatus;
    /**
     * 流程实例ID 精确
     */
    @ApiModelProperty("流程实例ID")
    private String apprProcInstId;
    /**
     * 精确
     */
    @ApiModelProperty("")
    private String extString1;
    /**
     * 精确
     */
    @ApiModelProperty("")
    private String extString2;
    /**
     * 精确
     */
    @ApiModelProperty("")
    private String extString3;
    /**
     * 精确
     */
    @ApiModelProperty("")
    private String extString4;
    /**
     * 精确
     */
    @ApiModelProperty("")
    private String extString5;
}

==> tw-api-5.0.91-20240725.095514-1-sources.jar: com/elitesland/tw/tw5/api/prd/personplan/query/PersonPlanVersionQuery.java <==
package com.elitesland.tw.tw5.api.prd.personplan.query;

import com.elitesland.tw.tw5.api.common.TwQueryParam;
import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;

import java.io.Serializable;

/**
 * 人员规划版本
 *
 * @author wangly
 * @date 2024-04-07
 */
@Getter
@Setter
public class PersonPlanVersionQuery extends TwQueryParam implements Serializable {
    /**
     * 记录唯一ID 精确
     */
    @ApiModelProperty("记录唯一ID")
    private Long id;
    /**
     * 资源规划主表id
     */
    @ApiModelProperty("资源规划主表id")
    private Long planId;
    /**
     * 类型 精确
     */
    @ApiModelProperty("类型")
    private String planType;
    /**
     * 版本名称 精确
     */
    @ApiModelProperty("版本名称")
    private String versionName;
    /**
     * 版本信息 精确
     */
    @ApiModelProperty("版本信息")
    private String changeContent;
    /**
     * 变更单据id 精确
     */
    @ApiModelProperty("变更单据id")
    private Long objId;
    /**
     * 版本号 精确
     */
    @ApiModelProperty("版本号")
    private Integer versionNo;
    /**
     * 变更状态 精确
     */
    @ApiModelProperty("变更状态")
    private String status;
    /**
     * 流程状态 精确
     */
    @ApiModelProperty("流程状态")
    private String apprStatus;
    /**
     * 流程实例ID 精确
     */
    @ApiModelProperty("流程实例ID")
    private String procInstId;
    /**
     * 精确
     */
    @ApiModelProperty("")
    private String extString1;
    /**
     * 精确
     */
    @ApiModelProperty("")
    private String extString2;
    /**
     * 精确
     */
    @ApiModelProperty("")
    private String extString3;
    /**
     * 精确
     */
    @ApiModelProperty("")
    private String extString4;
    /**
     * 精确
     */
    @ApiModelProperty("")
    private String extString5;
}
